@@ -1,5 +1,5 @@
 package Lingua::EN::Numbers::Years;
-$Lingua::EN::Numbers::Years::VERSION = '1.04';
+$Lingua::EN::Numbers::Years::VERSION = '1.05';
 use 5.006;
 use strict;
 use warnings;
@@ -136,9 +136,13 @@ Note that C<year2en> doesn't try to append "BC" or "AD".
 
 =head1 SEE ALSO
 
-L<Lingua::EN::Numbers>
+L<Lingua::EN::Numbers> - more general purpose module for turning
+numbers into English text.
+
+L<Lingua::EN::Words2Nums> - another general purpose module
+for converting numbers into English text.
+I'd recommend using the previous module.
 
-L<Lingua::EN::WordsToNumbers>
 
 =head1 REPOSITORY
 
